/*--------------------------------------------------------------------------+
$Id: codetemplates.xml 1 2011-01-01 00:00:01Z hoelzl $
|                                                                          |
| Copyright 2017 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.util;

import static org.fortiss.tooling.base.utils.LayoutModelElementFactory.createConnectorLayout;

import org.fortiss.af3.platform.raspberry.model.ActuatorConnector;
import org.fortiss.af3.platform.raspberry.model.ActuatorPWM;
import org.fortiss.af3.platform.raspberry.model.CanBus;
import org.fortiss.af3.platform.raspberry.model.CanConnector;
import org.fortiss.af3.platform.raspberry.model.GPI;
import org.fortiss.af3.platform.raspberry.model.GPO;
import org.fortiss.af3.platform.raspberry.model.ModelFactory;
import org.fortiss.af3.platform.raspberry.model.RaspberryPi;
import org.fortiss.af3.platform.raspberry.model.SensorConnector;
import org.fortiss.af3.platform.raspberry.model.SensorGamepad;
import org.fortiss.af3.platform.raspberry.model.SensorIMU;
import org.fortiss.af3.platform.raspberry.model.SensorLaserRangeFinder;
import org.fortiss.af3.platform.raspberry.model.SensorLaserScanner;
import org.fortiss.af3.platform.raspberry.model.gamepad.Button1;
import org.fortiss.af3.platform.raspberry.model.gamepad.Button2;
import org.fortiss.af3.platform.raspberry.model.gamepad.Button3;
import org.fortiss.af3.platform.raspberry.model.gamepad.Button4;
import org.fortiss.af3.platform.raspberry.model.gamepad.ButtonL1;
import org.fortiss.af3.platform.raspberry.model.gamepad.ButtonL2;
import org.fortiss.af3.platform.raspberry.model.gamepad.ButtonR1;
import org.fortiss.af3.platform.raspberry.model.gamepad.ButtonR2;
import org.fortiss.af3.platform.raspberry.model.gamepad.GamepadFactory;
import org.fortiss.af3.platform.raspberry.model.gamepad.Left_StickX_Position;
import org.fortiss.af3.platform.raspberry.model.gamepad.Left_StickY_Position;
import org.fortiss.af3.platform.raspberry.model.gamepad.Right_StickX_Position;
import org.fortiss.af3.platform.raspberry.model.gamepad.Right_StickY_Position;
import org.fortiss.tooling.base.utils.LayoutModelElementFactory;

/**
 * Model Element for RaspberryPi and related models.
 * 
 * @author eder
 * @author $Author: hoelzl $
 * @version $Rev: 18709 $
 * @ConQAT.Rating RED Hash:
 */
public class RaspberryModelElementFactory {

	/** Creates a {@link RaspberryPi}. */
	public static RaspberryPi createRaspberryPi() {
		final RaspberryPi pi = ModelFactory.eINSTANCE.createRaspberryPi();
		LayoutModelElementFactory.createNodeElementLayout(pi);
		pi.setName("RaspberryPI");
		return pi;
	}

	/** Creates a {@link CanBus}. */
	public static CanBus createCanBus() {
		final CanBus bus = ModelFactory.eINSTANCE.createCanBus();
		LayoutModelElementFactory.createNodeElementLayout(bus);
		bus.setName("CanBus");
		return bus;
	}

	/** Creates a {@link CanConnector}. */
	public static CanConnector createCanConnector() {
		CanConnector canConnector = ModelFactory.eINSTANCE.createCanConnector();
		canConnector.setName("CanConnector");
		createConnectorLayout(canConnector);
		return canConnector;
	}

	/** Creates a {@link SensorConnector}. */
	public static SensorConnector createSensorConnector() {
		SensorConnector connector = ModelFactory.eINSTANCE.createSensorConnector();
		connector.setName("Sensor");
		createConnectorLayout(connector);
		return connector;
	}

	/** Creates a {@link SensorGamepad} */
	public static SensorGamepad createGamepadSensor() {
		SensorGamepad connector = ModelFactory.eINSTANCE.createSensorGamepad();
		connector.setName("Gamepad_In");
		createConnectorLayout(connector);
		return connector;
	}

	/** Creates a {@link SensorIMU}. */
	public static SensorIMU createSensorIMU() {
		SensorIMU connector = ModelFactory.eINSTANCE.createSensorIMU();
		connector.setName("IMU_In");
		createConnectorLayout(connector);
		return connector;
	}

	/** Creates a {@link SensorLaserRangeFinder}. */
	public static SensorLaserRangeFinder createSensorLaserRangeFinder() {
		SensorLaserRangeFinder connector = ModelFactory.eINSTANCE.createSensorLaserRangeFinder();
		connector.setName("LaserRangeFinder_In");
		createConnectorLayout(connector);
		return connector;
	}

	/** Creates a {@link SensorLaserScanner}. */
	public static SensorLaserScanner createSensorLaserScanner() {
		SensorLaserScanner connector = ModelFactory.eINSTANCE.createSensorLaserScanner();
		connector.setName("LaserScanner_In");
		createConnectorLayout(connector);
		return connector;
	}

	/** Creates a {@link ActuatorConnector}. */
	public static ActuatorConnector createActuatorConnector() {
		ActuatorConnector connector = ModelFactory.eINSTANCE.createActuatorConnector();
		connector.setName("Sensor");
		createConnectorLayout(connector);
		return connector;
	}

	/** Creates a {@link ActuatorPWM}. */
	public static ActuatorPWM createActuatorPWM() {
		ActuatorPWM connector = ModelFactory.eINSTANCE.createActuatorPWM();
		connector.setName("PWM_Out");
		createConnectorLayout(connector);
		return connector;
	}

	/** Creates a {@link GPI}. */
	public static GPI createGPI() {
		GPI gpi = ModelFactory.eINSTANCE.createGPI();
		gpi.setName("GPI");
		createConnectorLayout(gpi);
		return gpi;
	}

	/** Creates a {@link GPI}. */
	public static GPO createGPO() {
		GPO gpo = ModelFactory.eINSTANCE.createGPO();
		gpo.setName("GPO");
		createConnectorLayout(gpo);
		return gpo;
	}

	/** Creates a {@link Button1}. */
	public static Button1 createButton1() {
		Button1 button = GamepadFactory.eINSTANCE.createButton1();
		button.setName("Button1_Triangle");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link Button2}. */
	public static Button2 createButton2() {
		Button2 button = GamepadFactory.eINSTANCE.createButton2();
		button.setName("Button1_Circle_");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link Button3}. */
	public static Button3 createButton3() {
		Button3 button = GamepadFactory.eINSTANCE.createButton3();
		button.setName("Button3_X");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link Button4}. */
	public static Button4 createButton4() {
		Button4 button = GamepadFactory.eINSTANCE.createButton4();
		button.setName("Button4_Square");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link ButtonL1}. */
	public static ButtonL1 createButtonL1() {
		ButtonL1 button = GamepadFactory.eINSTANCE.createButtonL1();
		button.setName("ButtonL1");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link ButtonR2}. */
	public static ButtonR2 createButtonR2() {
		ButtonR2 button = GamepadFactory.eINSTANCE.createButtonR2();
		button.setName("ButtonR2");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link ButtonL2}. */
	public static ButtonL2 createButtonL2() {
		ButtonL2 button = GamepadFactory.eINSTANCE.createButtonL2();
		button.setName("ButtonL2");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link ButtonR1}. */
	public static ButtonR1 createButtonR1() {
		ButtonR1 button = GamepadFactory.eINSTANCE.createButtonR1();
		button.setName("ButtonR1");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link Left_StickX_Position}. */
	public static Left_StickX_Position createLeftStickX() {
		Left_StickX_Position button = GamepadFactory.eINSTANCE.createLeft_StickX_Position();
		button.setName("Left_StickX");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link Left_StickY_Position}. */
	public static Left_StickY_Position createLeftStickY() {
		Left_StickY_Position button = GamepadFactory.eINSTANCE.createLeft_StickY_Position();
		button.setName("Left_StickY");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link Right_StickX_Position}. */
	public static Right_StickX_Position createRightStickX() {
		Right_StickX_Position button = GamepadFactory.eINSTANCE.createRight_StickX_Position();
		button.setName("Right_StickX");
		createConnectorLayout(button);
		return button;
	}

	/** Creates a {@link Right_StickY_Position}. */
	public static Right_StickY_Position createRightStickY() {
		Right_StickY_Position button = GamepadFactory.eINSTANCE.createRight_StickY_Position();
		button.setName("Right_StickY");
		createConnectorLayout(button);
		return button;
	}

}
